@@ -12,6 +12,7 @@ from typing import TYPE_CHECKING, TypeVar
 import requests
 
 from citric import enums
+from citric._compat import future
 from citric.session import Session
 
 if TYPE_CHECKING:
@@ -20,6 +21,11 @@ if TYPE_CHECKING:
     from types import TracebackType
     from typing import Any, BinaryIO, Generator, Iterable, Mapping, Sequence
 
+    from typing_extensions import Unpack
+
+    from citric import types
+    from citric.objects import Participant
+
     if sys.version_info >= (3, 8):
         from typing import Literal
     else:
@@ -157,7 +163,7 @@ class Client:
         """
         return self.__session.get_fieldmap(survey_id)
 
-    def activate_survey(self, survey_id: int) -> dict[str, Any]:
+    def activate_survey(self, survey_id: int) -> types.OperationStatus:
         """Activate a survey.
 
         Args:
@@ -172,7 +178,7 @@ class Client:
         self,
         survey_id: int,
         attributes: list[int] | None = None,
-    ) -> dict[str, str]:
+    ) -> types.OperationStatus:
         """Initialise the survey participant table.
 
         New participant tokens may be later added.
@@ -186,7 +192,7 @@ class Client:
         """
         return self.__session.activate_tokens(survey_id, attributes or [])
 
-    def add_language(self, survey_id: int, language: str) -> dict[str, Any]:
+    def add_language(self, survey_id: int, language: str) -> types.OperationStatus:
         """Add a survey language.
 
         Args:
@@ -222,12 +228,57 @@ class Client:
             create_tokens,
         )
 
+    @future("6.0")
+    def add_quota(
+        self,
+        survey_id: int,
+        name: str,
+        limit: int,
+        *,
+        active: bool = True,
+        action: str = enums.QuotaAction.TERMINATE,
+        autoload_url: bool = False,
+        message: str = "",
+        url: str = "",
+        url_description: str = "",
+    ) -> int:
+        """Add a quota to a LimeSurvey survey.
+
+        Args:
+            survey_id: ID of the survey to add the quota to.
+            name: Name of the quota.
+            limit: Limit of the quota.
+            active: Whether the quota is active.
+            action: Action to take when the limit is reached.
+            autoload_url: Whether to automatically load the URL.
+            message: Message to display to the respondent when the limit is reached.
+            url: URL to redirect the respondent to when the limit is reached.
+            url_description: Description of the URL.
+
+        Returns:
+            ID of the newly created quota.
+
+        .. versionadded:: 0.6.0
+        .. future:: 6.0
+        """
+        return self.session.add_quota(
+            survey_id,
+            name,
+            limit,
+            active,
+            enums.QuotaAction(action),
+            autoload_url,
+            message,
+            url,
+            url_description,
+        )
+
     def add_survey(
         self,
         survey_id: int,
         title: str,
         language: str,
-        survey_format: str = "G",
+        survey_format: str | enums.NewSurveyType = "G",
     ) -> int:
         """Add a new empty survey.
 
@@ -270,7 +321,7 @@ class Client:
     def _get_question_mapping(
         self,
         survey_id: int,
-    ) -> dict[str, dict[str, Any]]:
+    ) -> dict[str, types.QuestionsListElement]:
         """Get question mapping.
 
         Args:
@@ -284,7 +335,7 @@ class Client:
     @staticmethod
     def _map_response_keys(
         response_data: Mapping[str, Any],
-        question_mapping: dict[str, dict[str, Any]],
+        question_mapping: dict[str, types.QuestionsListElement],
     ) -> dict[str, Any]:
         """Convert response keys to LimeSurvey's internal representation.
 
@@ -413,6 +464,28 @@ class Client:
         """
         return self.__session.copy_survey(survey_id, name)
 
+    def import_cpdb_participants(
+        self,
+        participants: Sequence[Participant],
+        *,
+        update: bool = False,
+    ) -> types.CPDBParticipantImportResult:
+        """Import CPDB participants.
+
+        Args:
+            participants: CPDB participant data.
+            update: Whether to update existing participants.
+
+        Returns:
+            IDs of the new participants.
+
+        .. versionadded:: 0.7.0
+        """
+        return self.session.cpd_importParticipants(
+            [participant.to_dict() for participant in participants],
+            update,
+        )
+
     def delete_group(self, survey_id: int, group_id: int) -> int:
         """Delete a group.
 
@@ -425,7 +498,7 @@ class Client:
         """
         return self.__session.delete_group(survey_id, group_id)
 
-    def delete_language(self, survey_id: int, language: str) -> dict[str, str]:
+    def delete_language(self, survey_id: int, language: str) -> types.OperationStatus:
         """Delete a language from a survey.
 
         Requires at LimeSurvey >= 5.3.4.
@@ -439,7 +512,26 @@ class Client:
         """
         return self.__session.delete_language(survey_id, language)
 
-    def delete_response(self, survey_id: int, response_id: int) -> dict[str, str]:
+    @future("6.0")
+    def delete_quota(self, quota_id: int) -> types.OperationStatus:
+        """Delete a LimeSurvey quota.
+
+        Args:
+            quota_id: ID of the quota to delete.
+
+        Returns:
+            True if the quota was deleted.
+
+        .. versionadded:: 0.6.0
+        .. future:: 6.0
+        """
+        return self.session.delete_quota(quota_id)
+
+    def delete_response(
+        self,
+        survey_id: int,
+        response_id: int,
+    ) -> types.OperationStatus:
         """Delete a response in a survey.
 
         Args:
@@ -466,7 +558,7 @@ class Client:
         """
         return self.__session.delete_question(question_id)
 
-    def delete_survey(self, survey_id: int) -> dict[str, str]:
+    def delete_survey(self, survey_id: int) -> types.OperationStatus:
         """Delete a survey.
 
         Args:
@@ -482,11 +574,11 @@ class Client:
         survey_id: int,
         *,
         token: str | None = None,
-        file_format: str = "json",
+        file_format: str | enums.ResponsesExportFormat = "json",
         language: str | None = None,
-        completion_status: str = "all",
-        heading_type: str = "code",
-        response_type: str = "short",
+        completion_status: str | enums.SurveyCompletionStatus = "all",
+        heading_type: str | enums.HeadingType = "code",
+        response_type: str | enums.ResponseType = "short",
         from_response_id: int | None = None,
         to_response_id: int | None = None,
         fields: Sequence[str] | None = None,
@@ -591,7 +683,7 @@ class Client:
         self,
         survey_id: int,
         *,
-        file_format: str = "pdf",
+        file_format: str | enums.StatisticsExportFormat = "pdf",
         language: str | None = None,
         graph: bool = False,
         group_ids: list[int] | None = None,
@@ -659,7 +751,7 @@ class Client:
     def export_timeline(
         self,
         survey_id: int,
-        period: Literal["day", "hour"],
+        period: Literal["day", "hour"] | enums.TimelineAggregationPeriod,
         start: datetime.datetime,
         end: datetime.datetime | None = None,
     ) -> dict[str, int]:
@@ -689,7 +781,7 @@ class Client:
         *,
         settings: list[str] | None = None,
         language: str | None = None,
-    ) -> dict[str, Any]:
+    ) -> types.GroupProperties:
         """Get the properties of a group of a survey.
 
         Args:
@@ -708,7 +800,7 @@ class Client:
         *,
         settings: list[str] | None = None,
         language: str | None = None,
-    ) -> dict[str, Any]:
+    ) -> types.LanguageProperties:
         """Get survey language properties.
 
         Args:
@@ -746,7 +838,7 @@ class Client:
         *,
         settings: list[str] | None = None,
         language: str | None = None,
-    ) -> dict[str, Any]:
+    ) -> types.QuestionProperties:
         """Get properties of a question in a survey.
 
         Args:
@@ -759,6 +851,28 @@ class Client:
         """
         return self.__session.get_question_properties(question_id, settings, language)
 
+    @future("6.0")
+    def get_quota_properties(
+        self,
+        quota_id: int,
+        settings: list[str] | None = None,
+        language: str | None = None,
+    ) -> types.QuotaProperties:
+        """Get properties of a LimeSurvey quota.
+
+        Args:
+            quota_id: ID of the quota to get properties for.
+            settings: Properties to get, default to all.
+            language: Parameter language for multilingual quotas.
+
+        Returns:
+            Quota properties.
+
+        .. versionadded:: 0.6.0
+        .. future:: 6.0
+        """
+        return self.session.get_quota_properties(quota_id, settings, language)
+
     def get_response_ids(
         self,
         survey_id: int,
@@ -775,7 +889,19 @@ class Client:
         """
         return self.__session.get_response_ids(survey_id, token)
 
-    def _get_site_setting(self, setting_name: str) -> Any:  # noqa: ANN401
+    @future("6.0")
+    def get_available_site_settings(self) -> list[str]:
+        """Get all available site settings.
+
+        Returns:
+            A list of all the available site settings.
+
+        .. versionadded:: 0.6.0
+        .. future:: 6.0
+        """
+        return self.session.get_available_site_settings()
+
+    def _get_site_setting(self, setting_name: str) -> types.Result:
         """Get a global setting.
 
         Function to query site settings. Can only be used by super administrators.
@@ -847,7 +973,7 @@ class Client:
         self,
         survey_id: int,
         properties: Sequence[str] | None = None,
-    ) -> dict[str, Any]:
+    ) -> types.SurveyProperties:
         """Get properties of a survey.
 
         Args:
@@ -936,7 +1062,7 @@ class Client:
         self,
         file: BinaryIO,
         survey_id: int,
-        file_type: str = "lsg",
+        file_type: str | enums.ImportGroupType = "lsg",
     ) -> int:
         """Import group from a file.
 
@@ -990,7 +1116,7 @@ class Client:
     def import_survey(
         self,
         file: BinaryIO,
-        file_type: str = "lss",
+        file_type: str | enums.ImportSurveyType = "lss",
         survey_name: str | None = None,
         survey_id: int | None = None,
     ) -> int:
@@ -1077,7 +1203,7 @@ class Client:
         survey_id: int,
         group_id: int | None = None,
         language: str | None = None,
-    ) -> list[dict[str, Any]]:
+    ) -> list[types.QuestionsListElement]:
         """Get questions in a survey, in a specific group or all.
 
         Args:
@@ -1090,6 +1216,21 @@ class Client:
         """
         return self.__session.list_questions(survey_id, group_id, language)
 
+    @future("6.0")
+    def list_quotas(self, survey_id: int) -> list[types.QuotaListElement]:
+        """Get all quotas for a LimeSurvey survey.
+
+        Args:
+            survey_id: ID of the survey to get quotas for.
+
+        Returns:
+            List of quotas.
+
+        .. versionadded:: 0.6.0
+        .. future:: 6.0
+        """
+        return self.session.list_quotas(survey_id)
+
     def list_surveys(self, username: str | None = None) -> list[dict[str, Any]]:
         """Get all surveys or only those owned by a user.
 
@@ -1115,7 +1256,11 @@ class Client:
         """
         return self.__session.list_survey_groups(username)
 
-    def set_group_properties(self, group_id: int, **properties: Any) -> dict[str, bool]:
+    def set_group_properties(
+        self,
+        group_id: int,
+        **properties: Unpack[types.GroupProperties],
+    ) -> dict[str, bool]:
         """Set properties of a group.
 
         Args:
@@ -1131,7 +1276,7 @@ class Client:
         self,
         survey_id: int,
         language: str | None = None,
-        **properties: Any,
+        **properties: Unpack[types.LanguageProperties],
     ) -> dict[str, Any]:
         """Set properties of a survey language.
 
@@ -1172,7 +1317,7 @@ class Client:
         self,
         question_id: int,
         language: str | None = None,
-        **properties: Any,
+        **properties: Unpack[types.QuestionProperties],
     ) -> dict[str, bool]:
         """Set properties of a question.
 
@@ -1186,10 +1331,30 @@ class Client:
         """
         return self.session.set_question_properties(question_id, properties, language)
 
+    def set_quota_properties(
+        self,
+        quota_id: int,
+        **properties: Unpack[types.QuotaProperties],
+    ) -> types.SetQuotaPropertiesResult:
+        """Set properties of a quota.
+
+        Calls :rpc_method:`set_quota_properties`.
+
+        Args:
+            quota_id: Quota ID.
+            properties: Properties to set.
+
+        Returns:
+            Mapping with success status and updated properties.
+
+        .. versionadded:: 0.6.0
+        """
+        return self.session.set_quota_properties(quota_id, properties)
+
     def set_survey_properties(
         self,
         survey_id: int,
-        **properties: Any,
+        **properties: Unpack[types.SurveyProperties],
     ) -> dict[str, bool]:
         """Set properties of a survey.
 
@@ -1208,7 +1373,7 @@ class Client:
         field: str,
         filename: str,
         file: BinaryIO,
-    ) -> dict[str, Any]:
+    ) -> types.FileUploadResult:
         """Upload a file to a LimeSurvey survey.
 
         Args:
@@ -1230,7 +1395,7 @@ class Client:
         path: PathLike,
         *,
         filename: str | None = None,
-    ) -> dict[str, Any]:
+    ) -> types.FileUploadResult:
         """Upload a file to a LimeSurvey survey from a local path.
 
         Args:
